'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d4dc7860.js');

const sTooltipCss = ":host{all:initial;display:inline-block;--tooltip-display:none;--tooltip-left:0;--tooltip-top:0;--tooltip-arrow-right:unset;--tooltip-arrow-bottom:unset;--tooltip-arrow-left:unset;--tooltip-border-width:unset;--tooltip-border-color:unset;--tooltip-background-color:unset;--tooltip-max-width:unset;--tooltip-max-height:unset;--tooltip-opacity:unset}#tooltip-container{z-index:99999;pointer-events:none;display:var(--tooltip-display);position:fixed;left:var(--tooltip-left);top:var(--tooltip-top);opacity:var(--tooltip-opacity)}#tooltip-container.styled{background-color:var(--tooltip-background-color);border-radius:10px;padding:10px;color:white;max-width:var(--tooltip-max-width);max-height:var(--tooltip-max-height);border-style:solid;border-width:var(--tooltip-border-width);border-color:var(--tooltip-border-color)}#tooltip-container.styled:before,#tooltip-container.styled:after{content:\"\";width:0;height:0;position:absolute;border-style:solid}#tooltip-container.styled.top:before{border-left-width:10px;border-left-color:transparent;border-right-width:10px;border-right-color:transparent;border-bottom-width:10px;border-bottom-color:transparent;top:100%;left:50%;margin-left:-10px;border-top-width:calc(10px - var(--tooltip-border-width));border-top-color:var(--tooltip-border-color)}#tooltip-container.styled.top:after{border-left-width:calc(10px - var(--tooltip-border-width));border-left-color:transparent;border-right-width:calc(10px - var(--tooltip-border-width));border-right-color:transparent;border-bottom-width:calc(10px - var(--tooltip-border-width));border-bottom-color:transparent;top:100%;left:50%;margin-left:calc(-10px + var(--tooltip-border-width));border-top-color:var(--tooltip-background-color);border-top-width:calc(10px - var(--tooltip-border-width) * 2)}#tooltip-container.styled.bottom:before{border-left-width:10px;border-left-color:transparent;border-right-width:10px;border-right-color:transparent;border-top-width:10px;border-top-color:transparent;bottom:100%;left:50%;margin-left:-10px;border-bottom-width:calc(10px - var(--tooltip-border-width));border-bottom-color:var(--tooltip-border-color)}#tooltip-container.styled.bottom:after{border-left-width:calc(10px - var(--tooltip-border-width));border-left-color:transparent;border-right-width:calc(10px - var(--tooltip-border-width));border-right-color:transparent;border-top-width:calc(10px - var(--tooltip-border-width));border-top-color:transparent;bottom:100%;left:50%;margin-left:calc(-10px + var(--tooltip-border-width));border-bottom-color:var(--tooltip-background-color);border-bottom-width:calc(10px - var(--tooltip-border-width) * 2)}#tooltip-container.styled.left:before{border-top-width:10px;border-top-color:transparent;border-bottom-width:10px;border-bottom-color:transparent;border-right-width:10px;border-right-color:transparent;left:100%;top:50%;margin-top:-10px;border-left-width:calc(10px - var(--tooltip-border-width));border-left-color:var(--tooltip-border-color)}#tooltip-container.styled.left:after{border-top-width:calc(10px - var(--tooltip-border-width));border-top-color:transparent;border-bottom-width:calc(10px - var(--tooltip-border-width));border-bottom-color:transparent;border-right-width:calc(10px - var(--tooltip-border-width));border-right-color:transparent;left:100%;top:50%;margin-top:calc(-10px + var(--tooltip-border-width));border-left-color:var(--tooltip-background-color);border-left-width:calc(10px - var(--tooltip-border-width) * 2)}#tooltip-container.styled.right:before{border-top-width:10px;border-top-color:transparent;border-bottom-width:10px;border-bottom-color:transparent;border-left-width:10px;border-left-color:transparent;right:100%;top:50%;margin-top:-10px;border-right-width:calc(10px - var(--tooltip-border-width));border-right-color:var(--tooltip-border-color)}#tooltip-container.styled.right:after{border-top-width:calc(10px - var(--tooltip-border-width));border-top-color:transparent;border-bottom-width:calc(10px - var(--tooltip-border-width));border-bottom-color:transparent;border-left-width:calc(10px - var(--tooltip-border-width));border-left-color:transparent;right:100%;top:50%;margin-top:calc(-10px + var(--tooltip-border-width));border-right-color:var(--tooltip-background-color);border-right-width:calc(10px - var(--tooltip-border-width) * 2)}";

const STooltip = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this._isTooltipEnabled = false;
    this.margin = 10;
    this.orientation = 'bottom';
    this.followMouse = false;
    this.noDefaultStyle = false;
    this.backgroundColor = 'black';
    this.maxWidth = '500px';
    this.maxHeight = '300px';
    this.borderWidth = '0px';
    this.borderColor = 'white';
    this.opacity = .8;
  }
  get isTooltipEnabled() {
    return this._isTooltipEnabled;
  }
  set isTooltipEnabled(value) {
    if (value !== this._isTooltipEnabled) {
      this._isTooltipEnabled = value;
      this.hostElement.style.setProperty('--tooltip-display', value ? 'block' : 'none');
    }
  }
  updateBackgroundColor(value) {
    this.hostElement.style.setProperty('--tooltip-background-color', value);
  }
  updateMaxWidth(value) {
    this.hostElement.style.setProperty('--tooltip-max-width', value);
  }
  updateMaxHeight(value) {
    this.hostElement.style.setProperty('--tooltip-max-height', value);
  }
  updateBorderWidth(value) {
    this.hostElement.style.setProperty('--tooltip-border-width', value);
  }
  updateBorderColor(value) {
    this.hostElement.style.setProperty('--tooltip-border-color', value);
  }
  updateOpacity(value) {
    this.hostElement.style.setProperty('--tooltip-opacity', value.toString());
  }
  connectedCallback() {
    const parentElement = this.hostElement.parentElement;
    parentElement.addEventListener('mouseover', () => this.isTooltipEnabled = true);
    parentElement.addEventListener('mouseout', () => this.isTooltipEnabled = false);
    parentElement.addEventListener('mousemove', event => this.updateTooltipPosition(event));
    this.updateBackgroundColor(this.backgroundColor);
    this.updateMaxWidth(this.maxWidth);
    this.updateMaxHeight(this.maxHeight);
    this.updateBorderWidth(this.borderWidth);
    this.updateBorderColor(this.borderColor);
    this.updateOpacity(this.opacity);
  }
  render() {
    return (index.h(index.Host, null, index.h("div", { id: "tooltip-container", class: [
        this.orientation,
        this.noDefaultStyle ? '' : 'styled'
      ].join(' ') }, index.h("slot", null))));
  }
  updateTooltipPosition(mouseEvent) {
    let x = 0, y = 0;
    if (this.followMouse) {
      x = mouseEvent.x;
      y = mouseEvent.y;
    }
    else {
      const parentElement = this.hostElement.parentElement;
      const { top, right, bottom, left, width, height } = parentElement.getBoundingClientRect();
      switch (this.orientation) {
        case 'top':
          x = right - width / 2;
          y = top;
          break;
        case 'right':
          x = right;
          y = bottom - height / 2;
          break;
        case 'bottom':
          x = right - width / 2;
          y = bottom;
          break;
        case 'left':
          x = left;
          y = bottom - height / 2;
          break;
      }
    }
    this.setTooltipPosition(x, y);
  }
  setTooltipPosition(x, y) {
    const tooltipContainerElement = this.hostElement.shadowRoot.querySelector('#tooltip-container');
    const tooltipWidth = tooltipContainerElement.clientWidth;
    const tooltipHeight = tooltipContainerElement.clientHeight;
    let tooltipLeft = x;
    let tooltipTop = y;
    switch (this.orientation) {
      case 'top':
        tooltipLeft = x - tooltipWidth / 2;
        tooltipTop = y - tooltipHeight - this.margin;
        break;
      case 'right':
        tooltipLeft = x + this.margin;
        tooltipTop = y - tooltipHeight / 2;
        break;
      case 'bottom':
        tooltipLeft = x - tooltipWidth / 2;
        tooltipTop = y + this.margin;
        break;
      case 'left':
        tooltipLeft = x - tooltipWidth - this.margin;
        tooltipTop = y - tooltipHeight / 2;
        break;
    }
    this.hostElement.style.setProperty('--tooltip-left', `${tooltipLeft}px`);
    this.hostElement.style.setProperty('--tooltip-top', `${tooltipTop}px`);
  }
  get hostElement() { return index.getElement(this); }
  static get watchers() { return {
    "backgroundColor": ["updateBackgroundColor"],
    "maxWidth": ["updateMaxWidth"],
    "maxHeight": ["updateMaxHeight"],
    "borderWidth": ["updateBorderWidth"],
    "borderColor": ["updateBorderColor"],
    "opacity": ["updateOpacity"]
  }; }
};
STooltip.style = sTooltipCss;

exports.s_tooltip = STooltip;
